overlay_model library
Classes
- OverlayModel
- In tradition, we have to create an OverlayEntry passing into OverlayState.insert, and perform advance modification by OverlayEntry.markNeedsBuild or OverlayEntry.remove, basically. it's hard to distinguish the capability for each OverlayEntry when there is 2 or more entries, we cannot defined an OverlayEntry is removable, updatable, or insertable? it's possible that we just OverlayEntry.remove and find out the entry shouldn't be removed, or we just OverlayEntry.markNeedsBuild and find out the entry have nothing to be updated. it's danger to remove or update if we don't want to.
- OverlayPlan
- See Also
Mixins
-
OverlayFutureMixin<
T extends StatefulWidget> -
OverlayMixin<
T extends StatefulWidget> - In tradition, there are two way to insert overlay within a widget, both of them make code dirty:
-
OverlayStreamMixin<
T extends StatefulWidget>
Typedefs
- OverlayModelBuilder = Widget Function(BuildContext context, OverlayModel modal)